EXSWCPHIPT-125 - Add tests for hipGetDeviceCount and restructure some SpawnProc tests (#2765)

此提交包含在:
Jatin Chaudhary
2022-07-11 10:32:51 +01:00
提交者 GitHub
父節點 5b10765c6b
當前提交 9595654ddf
共有 12 個檔案被更改,包括 144 行新增33 行删除
-1
查看文件
@@ -27,7 +27,6 @@ add_subdirectory(event)
add_subdirectory(occupancy)
add_subdirectory(device)
add_subdirectory(printf)
add_subdirectory(printfExe)
add_subdirectory(texture)
add_subdirectory(streamperthread)
add_subdirectory(kernel)
+6
查看文件
@@ -18,7 +18,13 @@ set(TEST_SRC
hipDeviceGetUuid.cc
)
set_source_files_properties(hipGetDeviceCount.cc PROPERTIES COMPILE_FLAGS -std=c++17)
add_executable(getDeviceCount EXCLUDE_FROM_ALL getDeviceCount_exe.cc)
hip_add_exe_to_target(NAME DeviceTest
TEST_SRC ${TEST_SRC}
TEST_TARGET_NAME build_tests
COMPILE_OPTIONS -std=c++14)
add_dependencies(DeviceTest getDeviceCount)
+68
查看文件
@@ -0,0 +1,68 @@
/*
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
#include <hip/hip_runtime.h>
#include <iostream>
// Expects 1 command line arg, which is the Device Visible String
int main(int argc, char** argv) {
if (argc != 2) {
std::cerr << "Invalid number of args passed.\n"
<< "argc : " << argc << std::endl;
for (int i = 0; i < argc; i++) {
std::cerr << " argv[" << i << "] : " << argv[0] << std::endl;
}
std::cerr << "The program expects device visibility string i.e. 0,1,2" << std::endl;
return -1;
}
// disable visible_devices env from shell
#ifdef __HIP_PLATFORM_NVCC__
unsetenv("CUDA_VISIBLE_DEVICES");
setenv("CUDA_VISIBLE_DEVICES", argv[1], 1);
auto init_res = hipInit(0);
if (hipSuccess != init_res) {
std::cerr << "CUDA INIT API returned : " << hipGetErrorString(init_res) << std::endl;
return -1;
}
#else
unsetenv("ROCR_VISIBLE_DEVICES");
unsetenv("HIP_VISIBLE_DEVICES");
setenv("ROCR_VISIBLE_DEVICES", argv[1], 1);
setenv("HIP_VISIBLE_DEVICES", argv[1], 1);
#endif
int count = 0;
auto res = hipGetDeviceCount(&count);
if (hipSuccess != res) {
std::cerr << "HIP API returned : " << hipGetErrorString(res) << std::endl;
return -1;
}
#ifdef __HIP_PLATFORM_NVCC__
unsetenv("CUDA_VISIBLE_DEVICES");
#else
unsetenv("ROCR_VISIBLE_DEVICES");
unsetenv("HIP_VISIBLE_DEVICES");
#endif
return count;
}
+23
查看文件
@@ -23,6 +23,7 @@ THE SOFTWARE.
*/
#include <hip_test_common.hh>
#include <hip_test_process.hh>
/**
* hipGetDeviceCount tests
@@ -32,3 +33,25 @@ TEST_CASE("Unit_hipGetDeviceCount_NegTst") {
// Scenario1
REQUIRE_FALSE(hipGetDeviceCount(nullptr) == hipSuccess);
}
TEST_CASE("Unit_hipGetDeviceCount_HideDevices") {
int deviceCount = HipTest::getDeviceCount();
if (deviceCount < 2) {
HipTest::HIP_SKIP_TEST("This test requires more than 2 GPUs. Skipping.");
return;
}
for (int i = deviceCount; i >= 1; i--) {
std::string visibleStr;
for (int j = 0; j < i; j++) { // Generate a string which has first i devices
visibleStr += std::to_string(j);
if (j != (i - 1)) {
visibleStr += ",";
}
}
hip::SpawnProc proc("getDeviceCount", true);
INFO("Output from process : " << proc.getOutput());
REQUIRE(proc.run(visibleStr) == i);
}
}
+7
查看文件
@@ -16,3 +16,10 @@ elseif (HIP_PLATFORM MATCHES "nvidia")
TEST_TARGET_NAME build_tests
COMPILE_OPTIONS -std=c++17)
endif()
# Standalone exes
add_executable(printfFlags EXCLUDE_FROM_ALL printfFlags_exe.cc)
add_executable(printfSpecifiers EXCLUDE_FROM_ALL printfSpecifiers_exe.cc)
add_dependencies(printfTests printfFlags)
add_dependencies(printfTests printfSpecifiers)
+2 -16
查看文件
@@ -1,5 +1,5 @@
/*
Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
@@ -23,20 +23,6 @@ THE SOFTWARE.
#include <hip_test_common.hh>
#include <hip_test_process.hh>
__global__ void test_kernel() {
printf("%08d\n", 42);
printf("%08i\n", -42);
printf("%08u\n", 42);
printf("%08g\n", 123.456);
printf("%0+8d\n", 42);
printf("%+d\n", -42);
printf("%+08d\n", 42);
printf("%-8s\n", "xyzzy");
printf("% i\n", -42);
printf("%-16.8d\n", 42);
printf("%16.8d\n", 42);
}
TEST_CASE("Unit_printf_flags") {
std::string reference(R"here(00000042
-0000042
@@ -51,7 +37,7 @@ xyzzy
00000042
)here");
hip::SpawnProc proc("printfExe/printfFlags", true);
hip::SpawnProc proc("printfFlags", true);
REQUIRE(proc.run() == 0);
REQUIRE(proc.getOutput() == reference);
}
@@ -1,5 +1,5 @@
/*
Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
+2 -2
查看文件
@@ -1,5 +1,5 @@
/*
Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
@@ -89,7 +89,7 @@ x
)here");
#endif
hip::SpawnProc proc("printfExe/printfSepcifiers", true);
hip::SpawnProc proc("printfSpecifiers", true);
REQUIRE(0 == proc.run());
REQUIRE(proc.getOutput() == reference);
}
@@ -1,5 +1,5 @@
/*
Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
-5
查看文件
@@ -1,5 +0,0 @@
add_executable(printfFlags EXCLUDE_FROM_ALL printfFlags.cc)
add_executable(printfSepcifiers EXCLUDE_FROM_ALL printfSepcifiers.cc)
add_dependencies(build_tests printfFlags)
add_dependencies(build_tests printfSepcifiers)